# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hzdata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hzdata.proto',
  package='pb',
  syntax='proto3',
  serialized_options=b'Z\004.;pb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0chzdata.proto\x12\x02pb\"3\n\rHZDataRequest\x12\x12\n\nmethodName\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\x0c\"@\n\x0eHZDataResponse\x12\r\n\x05\x64\x61tas\x18\x01 \x01(\x0c\x12\x0f\n\x07\x65rrCode\x18\x02 \x01(\x05\x12\x0e\n\x06\x65rrMsg\x18\x03 \x01(\t2@\n\x06HZData\x12\x36\n\x0bHZDataQuery\x12\x11.pb.HZDataRequest\x1a\x12.pb.HZDataResponse\"\x00\x42\x06Z\x04.;pbb\x06proto3'
)




_HZDATAREQUEST = _descriptor.Descriptor(
  name='HZDataRequest',
  full_name='pb.HZDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='methodName', full_name='pb.HZDataRequest.methodName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='pb.HZDataRequest.params', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20,
  serialized_end=71,
)


_HZDATARESPONSE = _descriptor.Descriptor(
  name='HZDataResponse',
  full_name='pb.HZDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datas', full_name='pb.HZDataResponse.datas', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='pb.HZDataResponse.errCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='pb.HZDataResponse.errMsg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=137,
)

DESCRIPTOR.message_types_by_name['HZDataRequest'] = _HZDATAREQUEST
DESCRIPTOR.message_types_by_name['HZDataResponse'] = _HZDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HZDataRequest = _reflection.GeneratedProtocolMessageType('HZDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _HZDATAREQUEST,
  '__module__' : 'hzdata_pb2'
  # @@protoc_insertion_point(class_scope:pb.HZDataRequest)
  })
_sym_db.RegisterMessage(HZDataRequest)

HZDataResponse = _reflection.GeneratedProtocolMessageType('HZDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _HZDATARESPONSE,
  '__module__' : 'hzdata_pb2'
  # @@protoc_insertion_point(class_scope:pb.HZDataResponse)
  })
_sym_db.RegisterMessage(HZDataResponse)


DESCRIPTOR._options = None

_HZDATA = _descriptor.ServiceDescriptor(
  name='HZData',
  full_name='pb.HZData',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=139,
  serialized_end=203,
  methods=[
  _descriptor.MethodDescriptor(
    name='HZDataQuery',
    full_name='pb.HZData.HZDataQuery',
    index=0,
    containing_service=None,
    input_type=_HZDATAREQUEST,
    output_type=_HZDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HZDATA)

DESCRIPTOR.services_by_name['HZData'] = _HZDATA

# @@protoc_insertion_point(module_scope)



import os
import sys
from .api import *
from .hz_finance_service import *
from .utils import *

sys.modules["ROOT_DIR"] = os.path.abspath(os.path.dirname(__file__))

# p = os.path.dirname(__file__)
# print("hzdatasdk path=", p)

__all__ = [
    "cost_time"
]
__all__.extend(api.__all__)
__all__.extend(hz_finance_service.__all__)



from sqlalchemy.orm.query import Query
from .utils import *
from .choiceinfo import *
from .choice import *


# 获取财务类的sql语句
def get_finance_sql(query_object):
    if not isinstance(query_object, Query):
        raise AssertionError(
            "query_object must be a sqlalchemy's Query object."
            " But what passed in was: " + str(type(query_object))
        )

    # 编译 query 对象为纯 sql
    sql = compile_query(query_object)
    return sql


# choiceinfo库
caiwu_info_report = CaiwuInfoReport
caiwu_info_tradedate = CaiwuInfoTradedate

# choice库
csd_hs_gzzb_ltsz = CsdHsGzzbLtsz
csd_hs_zjlx_zljlr = CsdHsZjlxZljlr
css_hs_bbfz_yfzc = CssHsBbfzYfzc
css_hs_cwbb_xjllb_jyhdcsdxjll = CssHsCwbbXjllbJyhdcsdxjll
css_hs_cwbb_ybqy_lrb = CssHsCwbbYbqyLrb
css_hs_cwbb_ybqy_zcfzb = CssHsCwbbYbqyZcfzb
css_hs_cwfx_bgqttm = CssHsCwfxBgqttm
css_hs_cwfx_cznl = CssHsCwfxCznl
css_hs_cwfx_cznl_nnzzl = CssHsCwfxCznlNnzzl
css_hs_cwfx_cznl_tbzzl = CssHsCwfxCznlTbzzl
css_hs_cwfx_djdcwzb = CssHsCwfxDjdcwzb
css_hs_cwfx_mgzb = CssHsCwfxMgzb
css_hs_cwfx_mgzb_mgsyttm = CssHsCwfxMgzbMgsyttm
css_hs_cwfx_syzl = CssHsCwfxSyzl
css_hs_cwfx_xjll_ttm = CssHsCwfxXjllTtm
css_hs_cwfx_ylnl = CssHsCwfxYlnl
css_hs_cwfx_ylnl_jzcsylttm = CssHsCwfxYlnlJzcsylttm
css_hs_cwfx_yynl = CssHsCwfxYynl
css_hs_cwfx_zbjg = CssHsCwfxZbjg
css_hs_fhzb_fhzb = CssHsFhzbFhzb
css_hs_fxfx_zdycszb = CssHsFxfxZdycszb
css_hs_gbzb_gbbd = CssHsGbzbGbbd
# css_hs_gbzb_gbbd_bak = CssHsGbzbGbbdBak
css_hs_gdzb_bgqgdhszb = CssHsGdzbBgqgdhszb
css_hs_gdzb_gdggzjc = CssHsGdzbGdggzjc
css_hs_gdzb_gqzy = CssHsGdzbGqzy
css_hs_gdzb_hgtgzcg = CssHsGdzbHgtgzcg
css_hs_gdzb_jgcgbl = CssHsGdzbJgcgbl
css_hs_gdzb_sdgd = CssHsGdzbSdgd
css_hs_gpzb_fhzb = CssHsGpzbFhzb
css_hs_gpzb_pgzb = CssHsGpzbPgzb
css_hs_gpzb_zfzb = CssHsGpzbZfzb
css_hs_gzzb_bkhcgz = CssHsGzzbBkhcgz
css_hs_hqzb_qjhq = CssHsHqzbQjhq
css_hs_hqzb_rzrq = CssHsHqzbRzrq
css_hs_jbzl_zqzl_date = CssHsJbzlZqzlDate
css_hs_jgdyzb_ggrqjgdyzb = CssHsJgdyzbGgrqjgdyzb
# css_hs_lb.bak = CssHsLb.bak
css_hs_qq_yhbdl = CssHsQqYhbdl
css_hs_sfzb_sfssbx = CssHsSfzbSfssbx
css_hs_ylyc_org_info = CssHsYlycOrgInfo
css_hs_ylyc_ssgsyjyg = CssHsYlycSsgsyjyg
css_hs_ylyc_swhy_org_info = CssHsYlycSwhyOrgInfo
css_hs_ylyc_tzpjzhz = CssHsYlycTzpjzhz
css_hs_ylyc_ycyplmxz = CssHsYlycYcyplmxz
css_hs_ylyc_ycyplmxz_ybsl = CssHsYlycYcyplmxzYbsl
css_hs_ylyc_ylyczhz = CssHsYlycYlyczhz
css_hs_ylyc_ylyczhz_gd = CssHsYlycYlyczhzGd
css_hs_zcfz_fldzc = CssHsZcfzFldzc
css_jj_jjqbzb_jbzl = CssJjJjqbzbJbzl
css_jj_jjqbzb_tzzh_cgmx = CssJjJjqbzbTzzhCgmx
css_zs_gzzb_pettm = CssZsGzzbPettm
css_zs_hq_qjhq = CssZsHqQjhq
edb_hgsj_hl_rmbhl = EdbHgsjHlRmbhl
sector_hs_scl_abstock = SectorHsSclAbstock
sector_hs_scl_arrangestock = SectorHsSclArrangestock
sector_hs_scl_delistedstock = SectorHsSclDelistedstock
sector_hs_scl_issuingstock = SectorHsSclIssuingstock
sector_hs_scl_pendingstock = SectorHsSclPendingstock
sector_hs_scl_sststock = SectorHsSclSststock
sector_hs_scl_ststock = SectorHsSclStstock
sector_hs_scl_swhyfl_stock = SectorHsSclSwhyflStock



def _collect_item():
    items = []
    for item in globals().keys():
        for prefix in ["csd_", "css_", "caiwu_info_"]:
            if item.startswith(prefix):
                items.append(item)
    return items


__all__ = [
    "query",
    "get_finance_sql",
]

__all__.extend(_collect_item())

del _collect_item




# coding=utf-8

import threading
import grpc
import json
import msgpack
import numpy as np
import pandas as pd
# import hzdata_pb2
# import hzdata_pb2_grpc
from . import hzdata_pb2
from . import hzdata_pb2_grpc
import six
import zlib

from pandas.compat.pickle_compat import pkl, Unpickler, load as _load

MAX_MESSAGE_LENGTH = 20 * 1024 * 1024


class HZDataClient(object):
    _threading_local = threading.local()
    _default_addr = "10.34.1.253:10001"

    @classmethod
    def instance(cls):
        _instance = getattr(cls._threading_local, '_instance', None)
        if _instance is None:
            _instance = HZDataClient()
            cls._threading_local._instance = _instance
        return _instance

    def __init__(self):
        print("create HZDataClient object.")

    @classmethod
    def convert_message(cls, msg):
        if isinstance(msg, dict):
            data_type = msg.get("type", None)
            data_value = msg.get("value", None)
            if data_type is not None and data_value is not None:
                params = data_value
                if data_type.startswith("pandas"):
                    data_index_type = params.pop("index_type", None)
                    if data_index_type == "Index":
                        params["index"] = pd.Index(params["index"])
                    elif data_index_type == "MultiIndex":
                        params["index"] = (
                            pd.MultiIndex.from_tuples(params["index"])
                            if len(params["index"]) > 0 else None
                        )
                    if data_type == "pandas_dataframe":
                        dtypes = params.pop("dtypes", None)
                        msg = pd.DataFrame(**params)
                        if dtypes:
                            msg = msg.astype(dtypes, copy=False)
                    elif data_type == "pandas.core.series.Series":
                        msg = pd.Series(**params)
            else:
                msg = {
                    key: cls.convert_message(val)
                    for key, val in msg.items()
                }
        return msg

    def __call__(self, method, **kwargs):
        # 参数打包
        request = hzdata_pb2.HZDataRequest()
        request.methodName = method
        request.params = msgpack.packb(kwargs)

        # rpc请求
        channel = grpc.insecure_channel(self._default_addr, options=[
            ("grpc.max_send_message_length", MAX_MESSAGE_LENGTH),
            ("grpc.max_receive_message_length", MAX_MESSAGE_LENGTH)
        ])
        stub = hzdata_pb2_grpc.HZDataStub(channel)
        response = stub.HZDataQuery(request)

        # 是否触发异常
        if len(response.errMsg) > 0:
            raise Exception(response.errMsg)

        # 参数解包
        buffer = zlib.decompress(response.datas)
        file = six.BytesIO()
        file.write(buffer)
        msg = _load(file, encoding="latin1")

        return self.convert_message(msg)

    def __getattr__(self, method):
        return lambda **kwargs: self(method, **kwargs)
